==> haskell-http-common-0.8.3.4-157-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-J2tXXltyOupJSHdGmgNhWG
key:                  http-common-0.8.3.4-J2tXXltyOupJSHdGmgNhWG
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  b07d8ddbbae960575b0e8e4ad9c271db
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-J2tXXltyOupJSHdGmgNhWG
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-FdWgvlJbicB4WMe5vVN4jG
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT directory-1.3.6.2
    mtl-2.2.2 network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.3.4-162-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-GpZRqWqQpqt1uaGO8i3v6e
key:                  http-common-0.8.3.4-GpZRqWqQpqt1uaGO8i3v6e
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  eec9b541fb149d340597a7b8d47b2932
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-GpZRqWqQpqt1uaGO8i3v6e
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh directory-1.3.6.2
    mtl-2.2.2 network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
